@@ -118,6 +118,7 @@ AaModification::createInstance(const OboPsiModTerm &term)
   new_mod->setDiffFormula(term.m_diffFormula);
   new_mod->setXrefOrigin(term.m_origin);
   new_mod->m_name = term.m_name;
+  qDebug() << new_mod->m_mass;
   return new_mod;
 }
 
@@ -159,6 +160,22 @@ AaModification::createInstance(const QString &accession)
           // m_psiModLabel<<"|";
         }
     }
+  if(accession.startsWith("C13N15:"))
+    {
+      QRegularExpression regexp_label("^C13N15:([A-Z])$");
+      QRegularExpressionMatch match = regexp_label.match(accession);
+      if(match.hasMatch())
+        {
+          char labelled_aa(match.capturedTexts()[1].toStdString().c_str()[0]);
+
+          AaModificationP instance_labelled_aa_p =
+            createInstanceC13N15LabelledAminoAcid(QChar(labelled_aa));
+
+
+          return instance_labelled_aa_p;
+          // m_psiModLabel<<"|";
+        }
+    }
   // initMyResource();
   FilterOboPsiModSink term_list;
   FilterOboPsiModTermAccession filterm_accession(term_list, accession);
@@ -336,18 +353,26 @@ AaModification::calculateMassFromChemicalComponents()
   theoreticalm_mass += DIFFS32S36 * m_mapIsotope.at(Isotope::S36);
 
 
-  pappso_double diff = std::fabs((pappso_double)m_mass - theoreticalm_mass);
-  if(diff < 0.001)
+  if(m_mass == 0.0)
     {
       m_mass = theoreticalm_mass;
-      qDebug() << diff;
     }
   else
     {
-      qDebug()
-        << "ERROR in AaModification::calculateMassFromChemicalComponents theo="
-        << theoreticalm_mass << " m=" << m_mass << " diff=" << diff
-        << " accession=" << m_accession;
+      pappso_double diff = std::fabs((pappso_double)m_mass - theoreticalm_mass);
+      if(diff < 0.001)
+        {
+          m_mass = theoreticalm_mass;
+          qDebug() << diff;
+        }
+      else
+        {
+          qDebug()
+            << "ERROR in AaModification::calculateMassFromChemicalComponents "
+               "theo="
+            << theoreticalm_mass << " m=" << m_mass << " diff=" << diff
+            << " accession=" << m_accession;
+        }
     }
 }
 
@@ -421,21 +446,24 @@ AaModification::getInstance(const OboPsiModTerm &oboterm)
 {
 
   QMutexLocker locker(&m_mutex);
-  MapAccessionModifications::iterator it =
-    m_mapAccessionModifications.find(oboterm.m_accession);
-  if(it == m_mapAccessionModifications.end())
+
+  std::pair<MapAccessionModifications::iterator, bool> insert_res =
+    m_mapAccessionModifications.insert(
+      std::pair<QString, AaModificationP>(oboterm.m_accession, nullptr));
+
+  if(!insert_res.second)
     {
-      // not found
-      std::pair<MapAccessionModifications::iterator, bool> insert_res =
-        m_mapAccessionModifications.insert(std::pair<QString, AaModificationP>(
-          oboterm.m_accession, AaModification::createInstance(oboterm)));
-      it = insert_res.first;
+      // Failed to insert, was there already by same key.
     }
   else
     {
-      // found
+      // Could insert (albeit with nullptr), was not there already by same key.
+      // Just assign to the *correct* pair member the pointer to an
+      // extemporaneously allocated AaModification.
+      insert_res.first->second = AaModification::createInstance(oboterm);
     }
-  return it->second;
+
+  return insert_res.first->second;
 }
 
 
@@ -658,6 +686,100 @@ AaModification::getInstanceMutation(const QChar &mut_from, const QChar &mut_to)
                               .arg(accession)
                               .arg(e.what()));
     }
-} // namespace pappso
+}
+
+AaModificationP
+AaModification::createInstanceC13N15LabelledAminoAcid(const QChar &from_aa)
+{
+  switch(from_aa.toLatin1())
+    {
+      case 'R':
+        return createInstance("MOD:00587");
+        break;
+      case 'K':
+        return createInstance("MOD:00582");
+        break;
+      case 'F':
+        return createInstance("MOD:00589");
+        break;
+    }
+
+  // At this point we have no MOD ontology term for all the other amino-acid
+  // residue, we need to craft the stuff ourselves.
+
+  QString accession(QString("C13N15:%1").arg(from_aa));
+
+  // Define the diff formula for each amino acid code not handled above.
+
+  QString diff_formula;
+
+  switch(from_aa.toLatin1())
+    {
+      case 'G':
+        diff_formula = "(12)C -2 (13)C 2 (14)N -1 (15)N 1";
+        break;
+      case 'A':
+        diff_formula = "(12)C -3 (13)C 3 (14)N -1 (15)N 1";
+        break;
+      case 'V':
+        diff_formula = "(12)C -5 (13)C 5 (14)N -1 (15)N 1";
+        break;
+      case 'I':
+        diff_formula = "(12)C -6 (13)C 6 (14)N -1 (15)N 1";
+        break;
+      case 'L':
+        diff_formula = "(12)C -6 (13)C 6 (14)N -1 (15)N 1";
+        break;
+      case 'S':
+        diff_formula = "(12)C -3 (13)C 3 (14)N -1 (15)N 1";
+        break;
+      case 'T':
+        diff_formula = "(12)C -4 (13)C 4 (14)N -1 (15)N 1";
+        break;
+      case 'C':
+        diff_formula = "(12)C -3 (13)C 3 (14)N -1 (15)N 1";
+        break;
+      case 'M':
+        diff_formula = "(12)C -5 (13)C 5 (14)N -1 (15)N 1";
+        break;
+      case 'D':
+        diff_formula = "(12)C -4 (13)C 4 (14)N -1 (15)N 1";
+        break;
+      case 'E':
+        diff_formula = "(12)C -5 (13)C 5 (14)N -1 (15)N 1";
+        break;
+      case 'N':
+        diff_formula = "(12)C -4 (13)C 4 (14)N -2 (15)N 2";
+        break;
+      case 'Q':
+        diff_formula = "(12)C -5 (13)C 5 (14)N -2 (15)N 2";
+        break;
+      case 'W':
+        diff_formula = "(12)C -11 (13)C 11 (14)N -2 (15)N 2";
+        break;
+      case 'Y':
+        diff_formula = "(12)C -9 (13)C 9 (14)N -1 (15)N 1";
+        break;
+      case 'H':
+        diff_formula = "(12)C -6 (13)C 6 (14)N -3 (15)N 3";
+        break;
+      case 'P':
+        diff_formula = "(12)C -5 (13)C 5 (14)N -1 (15)N 1";
+        break;
+      default:
+        throw PappsoException(
+          QObject::tr("ERROR creating C13N15-labelled amino acid residue %1\n")
+            .arg(from_aa));
+    }
+
+  OboPsiModTerm obo_psi_term;
+  obo_psi_term.m_accession   = accession;
+  obo_psi_term.m_diffFormula = diff_formula;
+  obo_psi_term.m_name        = QString("Fully C13N15-labelled %1").arg(from_aa);
+  obo_psi_term.m_diffMono    = 0;
+
+  qDebug() << "obo_psi_term.m_diffFormula: " << obo_psi_term.m_diffFormula;
+  return AaModification::createInstance(obo_psi_term);
+}
 
 } // namespace pappso
