@@ -69,6 +69,8 @@ class PMSPP_LIB_DECL AaModification : public AtomNumberInterface
    */
   static AaModificationP getInstanceMutation(const QChar &mut_from,
                                              const QChar &mut_to);
+
+
   static AaModificationP getInstanceXtandemMod(const QString &type,
                                                pappso_double mass,
                                                const PeptideSp &peptide_sp,
@@ -107,6 +109,11 @@ class PMSPP_LIB_DECL AaModification : public AtomNumberInterface
   static AaModificationP createInstance(const OboPsiModTerm &term);
   static AaModificationP createInstanceMutation(const Aa &aa_from,
                                                 const Aa &aa_to);
+  /** @brief get heavy amino acid modification C13 N15
+   * @param aa_from orginal amino acid
+   */
+  static AaModificationP
+  createInstanceC13N15LabelledAminoAcid(const QChar &aa_from);
   void calculateMassFromChemicalComponents();
 
   using MapAccessionModifications = std::map<QString, AaModificationP>;
