@@ -21,6 +21,8 @@
 #include "../msrun/private/timsmsrunreaderms2.h"
 #include "../msrun/xymsrunreader.h"
 
+#include "../utils.h"
+
 
 namespace pappso
 {
@@ -78,9 +80,16 @@ MsFileAccessor::getMsRunIds()
   if(ms_run_ids.size())
     {
       // qDebug() << "Might well be handled using the Pwiz code.";
+      m_fileFormat     = pwiz_ms_file_reader.getFileFormat();
       m_fileReaderType = FileReaderType::pwiz;
 
-      m_fileFormat = pwiz_ms_file_reader.getFileFormat();
+      // But the user might have configured one preferred reader type.
+
+      auto pref = m_preferedFileReaderTypeMap.find(m_fileFormat);
+      if(pref != m_preferedFileReaderTypeMap.end())
+        {
+          m_fileReaderType = pref->second;
+        }
 
       return ms_run_ids;
     }
@@ -102,10 +111,10 @@ MsFileAccessor::getMsRunIds()
   if(ms_run_ids.size())
     {
       // qDebug() << "Might well be handled using the Bruker code";
-      m_fileReaderType = FileReaderType::tims;
-      m_fileFormat     = tims_file_reader.getFileFormat();
-      m_fileName       = tims_dir;
 
+      m_fileName       = tims_dir;
+      m_fileFormat     = tims_file_reader.getFileFormat();
+      m_fileReaderType = FileReaderType::tims;
 
       auto pref = m_preferedFileReaderTypeMap.find(m_fileFormat);
       if(pref != m_preferedFileReaderTypeMap.end())
@@ -113,8 +122,10 @@ MsFileAccessor::getMsRunIds()
           m_fileReaderType = pref->second;
         }
 
-        //qDebug() << "Returning Bruker::tims ms run(s).";
-      
+      // qDebug() << "Returning Bruker::tims ms run(s)."
+      //          << "with preferred reader type:"
+      //          << Utils::fileReaderTypeAsString(m_fileReaderType);
+
       return ms_run_ids;
     }
 
@@ -142,10 +153,45 @@ MsFileAccessor::getMsRunIds()
 }
 
 
+void
+MsFileAccessor::setPreferedFileReaderType(MzFormat format,
+                                          FileReaderType reader_type)
+{
+  auto ret = m_preferedFileReaderTypeMap.insert(
+    std::pair<MzFormat, FileReaderType>(format, reader_type));
+
+  if(!ret.second)
+    {
+      // replace
+      ret.first->second = reader_type;
+    }
+}
+
+
+FileReaderType
+MsFileAccessor::getPreferedFileReaderType(MzFormat format)
+{
+  auto ret = m_preferedFileReaderTypeMap.find(format);
+
+  if(ret != m_preferedFileReaderTypeMap.end())
+    {
+      return ret->second;
+    }
+
+  return m_fileReaderType;
+}
+
+
+FileReaderType
+MsFileAccessor::getFileReaderType() const
+{
+  return m_fileReaderType;
+}
+
+
 TimsMsRunReaderMs2SPtr
 MsFileAccessor::buildTimsMsRunReaderMs2SPtr()
 {
-
   // try TimsData reader
   QString tims_dir = m_fileName;
   if(!QFileInfo(tims_dir).isDir())
@@ -178,38 +224,41 @@ MsFileAccessor::buildTimsMsRunReaderMs2SPtr()
 MsRunReaderSPtr
 MsFileAccessor::msRunReaderSp(MsRunIdCstSPtr ms_run_id)
 {
+  // We want to return a MsRunReader that accounts for the configuration that
+  // the user might have set.
+
   if(m_fileName != ms_run_id->getFileName())
     throw(ExceptionNotPossible(
       QObject::tr("The MsRunId instance must have the name file name as the "
                   "MsFileAccessor.")));
 
-  if(m_fileReaderType == FileReaderType::pwiz)
+  if(getPreferedFileReaderType(m_fileFormat) == FileReaderType::pwiz)
     {
-      //qDebug() << "Returning a PwizMsRunReader.";
+      // qDebug() << "Returning a PwizMsRunReader.";
 
       return std::make_shared<PwizMsRunReader>(ms_run_id);
     }
-  else if(m_fileReaderType == FileReaderType::xy)
+  else if(getPreferedFileReaderType(m_fileFormat) == FileReaderType::xy)
     {
-      //qDebug() << "Returning a XyMsRunReader.";
+      // qDebug() << "Returning a XyMsRunReader.";
 
       return std::make_shared<XyMsRunReader>(ms_run_id);
     }
-  else if(m_fileReaderType == FileReaderType::tims)
+  else if(getPreferedFileReaderType(m_fileFormat) == FileReaderType::tims)
     {
-      //qDebug() << "Returning a TimsMsRunReader.";
+      // qDebug() << "Returning a TimsMsRunReader.";
 
       return std::make_shared<TimsMsRunReader>(ms_run_id);
     }
-  else if(m_fileReaderType == FileReaderType::tims_frames)
+  else if(getPreferedFileReaderType(m_fileFormat) == FileReaderType::tims_frames)
     {
-      //qDebug() << "Returning a TimsFramesMsRunReader.";
+      // qDebug() << "Returning a TimsFramesMsRunReader.";
 
       return std::make_shared<TimsFramesMsRunReader>(ms_run_id);
     }
-  else if(m_fileReaderType == FileReaderType::tims_ms2)
+  else if(getPreferedFileReaderType(m_fileFormat) == FileReaderType::tims_ms2)
     {
-      //qDebug() << "Returning a TimsMsRunReaderMs2.";
+      // qDebug() << "Returning a TimsMsRunReaderMs2.";
 
       return std::make_shared<TimsMsRunReaderMs2>(ms_run_id);
     }
@@ -224,7 +273,11 @@ MsFileAccessor::msRunReaderSp(MsRunIdCstSPtr ms_run_id)
           return std::make_shared<PwizMsRunReader>(ms_run_id);
         }
     }
-
+    else
+    {
+      throw PappsoException(QObject::tr("No file format was found."));
+    }
+    
   return nullptr;
 }
 
@@ -239,7 +292,6 @@ MsRunReaderSPtr
 MsFileAccessor::buildMsRunReaderSPtr(
   MsRunIdCstSPtr ms_run_id, pappso::FileReaderType prefered_file_reader_type)
 {
-
   QFile file(ms_run_id.get()->getFileName());
   if(!file.exists())
     throw(ExceptionNotFound(
@@ -250,7 +302,7 @@ MsFileAccessor::buildMsRunReaderSPtr(
 
   if(file_format == MzFormat::xy)
     {
-      //qDebug() << "Returning a XyMsRunReader.";
+      // qDebug() << "Returning a XyMsRunReader.";
 
       return std::make_shared<XyMsRunReader>(ms_run_id);
     }
@@ -260,7 +312,7 @@ MsFileAccessor::buildMsRunReaderSPtr(
         QObject::tr("unable to build a reader for %1 : unknown file format")
           .arg(QFileInfo(ms_run_id.get()->getFileName()).absoluteFilePath())));
     }
-  
+
   else if(file_format == MzFormat::brukerTims)
     {
       if(prefered_file_reader_type == pappso::FileReaderType::tims)
@@ -272,12 +324,12 @@ MsFileAccessor::buildMsRunReaderSPtr(
           return std::make_shared<TimsMsRunReaderMs2>(ms_run_id);
         }
 
-      //qDebug() << "by default, build a TimsMsRunReader.";
+      // qDebug() << "by default, build a TimsMsRunReader.";
       return std::make_shared<TimsMsRunReader>(ms_run_id);
     }
   else
     {
-      //qDebug() << "Returning a PwizMsRunReader .";
+      // qDebug() << "Returning a PwizMsRunReader .";
 
       return std::make_shared<PwizMsRunReader>(ms_run_id);
     }
@@ -320,23 +372,5 @@ MsFileAccessor::getMsRunReaderSPtrByRunId(const QString &run_id,
   return reader_sp;
 }
 
-void
-MsFileAccessor::setPreferedFileReaderType(MzFormat format,
-                                          FileReaderType reader_type)
-{
-  auto ret = m_preferedFileReaderTypeMap.insert(
-    std::pair<MzFormat, FileReaderType>(format, reader_type));
 
-  if(!ret.second)
-    {
-      // replace
-      ret.first->second = reader_type;
-    }
-}
-
-FileReaderType
-MsFileAccessor::getFileReaderType() const
-{
-  return m_fileReaderType;
-}
 } // namespace pappso
