@@ -17,15 +17,6 @@ namespace pappso
 class TimsMsRunReaderMs2;
 typedef std::shared_ptr<TimsMsRunReaderMs2> TimsMsRunReaderMs2SPtr;
 
-enum class FileReaderType
-{
-  pwiz,
-  xy,
-  tims,
-  tims_frames,
-  tims_ms2,
-};
-
 // This class is used to access mass spectrometry data files. The file being
 // opened and read might contain more than one MS run. The user of this class
 // might request a vector of all these MS runs (in the form of a vector of
@@ -52,7 +43,8 @@ class PMSPP_LIB_DECL MsFileAccessor
   /** @brief given an mz format, explicitly set the prefered reader
    */
   void setPreferedFileReaderType(MzFormat format, FileReaderType reader_type);
-
+  FileReaderType getPreferedFileReaderType(MzFormat format);
+  
   std::vector<MsRunIdCstSPtr> getMsRunIds();
 
   MsRunReaderSPtr msRunReaderSp(MsRunIdCstSPtr ms_run_id);
