@@ -789,6 +789,13 @@ PwizMsRunReader::readSpectrumCollection(
   readSpectrumCollectionByMsLevel(handler, 0);
 }
 
+void
+PwizMsRunReader::readSpectrumCollection2(
+  [[maybe_unused]] const MsRunReadConfig &config,
+  SpectrumCollectionHandlerInterface &handler)
+{
+  readSpectrumCollectionByMsLevel(handler, 0);
+}
 
 void
 PwizMsRunReader::readSpectrumCollectionByMsLevel(
