@@ -27,6 +27,7 @@
 
 #include "timsmsrunreader.h"
 #include "../../exception/exceptionnotimplemented.h"
+#include "../../exception/exceptioninterrupted.h"
 #include <QDebug>
 
 using namespace pappso;
@@ -100,6 +101,12 @@ TimsMsRunReader::readSpectrumCollection(
   readSpectrumCollectionByMsLevel(handler, 0);
 }
 
+void
+TimsMsRunReader::readSpectrumCollection2([[maybe_unused]] const MsRunReadConfig &config,
+                          SpectrumCollectionHandlerInterface &handler)
+{
+  return readSpectrumCollection(handler);
+}
 
 void
 TimsMsRunReader::readSpectrumCollectionByMsLevel(
@@ -108,9 +115,17 @@ TimsMsRunReader::readSpectrumCollectionByMsLevel(
 
   qDebug();
 
+  try
+    {
 
-  msp_timsData.get()->rawReaderSpectrumCollectionByMsLevel(
-    getMsRunId(), handler, ms_level);
+      msp_timsData.get()->rawReaderSpectrumCollectionByMsLevel(
+        getMsRunId(), handler, ms_level);
+    }
+
+  catch(ExceptionInterrupted &)
+    {
+      qDebug() << "Reading of MS data interrupted by the user.";
+    }
 
   // Now let the loading handler know that the loading of the data has ended.
   // The handler might need this "signal" to perform additional tasks or to
@@ -192,6 +207,6 @@ TimsMsRunReader::getTicChromatogram()
 
   acquireDevice();
 
+  // The time unit here is seconds, not minutes!!!
   return msp_timsData->getTicChromatogram();
 }
-
