@@ -56,6 +56,9 @@ class TimsMsRunReader : public MsRunReader
   virtual void
   readSpectrumCollection(SpectrumCollectionHandlerInterface &handler) override;
 
+  virtual void
+  readSpectrumCollection2(const MsRunReadConfig &config,
+                          SpectrumCollectionHandlerInterface &handler) override;
   virtual void
   readSpectrumCollectionByMsLevel(SpectrumCollectionHandlerInterface &handler,
                                   unsigned int ms_level) override;
