@@ -133,6 +133,56 @@ Peptide::makeNoConstPeptideSp() const
   return std::make_shared<Peptide>(*this);
 }
 
+
+std::vector<Aa>::iterator
+Peptide::begin()
+{
+  return m_aaVec.begin();
+}
+
+std::vector<Aa>::iterator
+Peptide::end()
+{
+  return m_aaVec.end();
+}
+
+std::vector<Aa>::const_iterator
+Peptide::begin() const
+{
+  return m_aaVec.begin();
+}
+
+std::vector<Aa>::const_iterator
+Peptide::end() const
+{
+  return m_aaVec.end();
+}
+
+std::vector<Aa>::const_reverse_iterator
+Peptide::rbegin() const
+{
+  return m_aaVec.rbegin();
+}
+
+std::vector<Aa>::const_reverse_iterator
+Peptide::rend() const
+{
+  return m_aaVec.rend();
+}
+
+
+pappso_double
+Peptide::getMass() const
+{
+  return m_proxyMass;
+}
+
+
+unsigned int
+Peptide::size() const
+{
+  return m_aaVec.size();
+}
 void
 Peptide::addAaModification(AaModificationP aaModification,
                            unsigned int position)
@@ -150,6 +200,23 @@ Peptide::addAaModification(AaModificationP aaModification,
   qDebug() << "Peptide::addAaModification end";
 }
 
+void
+Peptide::addAaModificationOnAllAminoAcid(AaModificationP aaModification,
+                                         AminoAcidChar amino_acid)
+{
+
+  for(auto &aa : *this)
+    {
+      if(aa.getAminoAcidChar() == amino_acid)
+        {
+          aa.addAaModification(aaModification);
+        }
+    }
+
+
+  m_proxyMass = -1;
+  getMass();
+}
 
 const QString
 Peptide::getSequence() const
