@@ -129,63 +129,38 @@ class PMSPP_LIB_DECL Peptide : public PeptideInterface
    * */
   void addAaModification(AaModificationP aaModification, unsigned int position);
 
-  std::vector<Aa>::iterator
-  begin()
-  {
-    return m_aaVec.begin();
-  }
+  /** @brief adds a modification to all amino acid of the sequence
+   * @param aaModification pointer on modification to add
+   * @param AminoAcidChar amino_acid to apply the modification
+   * */
+  void addAaModificationOnAllAminoAcid(AaModificationP aaModification,
+                                       AminoAcidChar amino_acid);
 
-  std::vector<Aa>::iterator
-  end()
-  {
-    return m_aaVec.end();
-  }
+  std::vector<Aa>::iterator begin();
 
-  std::vector<Aa>::const_iterator
-  begin() const
-  {
-    return m_aaVec.begin();
-  }
+  std::vector<Aa>::iterator end();
 
-  std::vector<Aa>::const_iterator
-  end() const
-  {
-    return m_aaVec.end();
-  }
+  std::vector<Aa>::const_iterator begin() const;
 
-  std::vector<Aa>::const_reverse_iterator
-  rbegin() const
-  {
-    return m_aaVec.rbegin();
-  }
+  std::vector<Aa>::const_iterator end() const;
 
-  std::vector<Aa>::const_reverse_iterator
-  rend() const
-  {
-    return m_aaVec.rend();
-  }
+  std::vector<Aa>::const_reverse_iterator rbegin() const;
+
+  std::vector<Aa>::const_reverse_iterator rend() const;
 
   Aa &getAa(unsigned int position);
   const Aa &getConstAa(unsigned int position) const;
 
 
   pappso_double getMass();
-  pappso_double
-  getMass() const override
-  {
-    return m_proxyMass;
-  };
+  pappso_double getMass() const override;
 
   virtual int getNumberOfAtom(AtomIsotopeSurvey atom) const override;
   virtual int getNumberOfIsotope(Isotope isotope) const override;
 
   /** \brief print amino acid sequence without modifications */
   const QString getSequence() const override;
-  unsigned int
-  size() const override
-  {
-    return m_aaVec.size();
-  };
+  unsigned int size() const override;
 
   /** @brief count modification occurence
    * @param mod modification to look for
