@@ -80,9 +80,8 @@ PeptideNaturalIsotopeAverage::PeptideNaturalIsotopeAverage(
   std::vector<PeptideNaturalIsotopeSp> v_isotope_list(
     isotopeList.getByIsotopeNumber(isotope_number, m_z));
 
-  // qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__
-  //       << "v_isotope_list.size()=" << v_isotope_list.size() << " "
-  //     << isotope_number << " " << askedIsotopeRank;
+  qDebug() << "v_isotope_list.size()=" << v_isotope_list.size() << " "
+           << isotope_number << " " << askedIsotopeRank;
   m_abundanceRatio = 0;
   m_averageMz      = 0;
   if(askedIsotopeRank > v_isotope_list.size())
@@ -272,3 +271,4 @@ PeptideNaturalIsotopeAverage::toString() const
     .arg(getIsotopeNumber());
 }
 } // namespace pappso
+
