@@ -82,20 +82,20 @@ MzIntegrationParams::MzIntegrationParams(pappso::pappso_double minMz,
                                          BinningType binningType,
                                          int decimalPlaces,
                                          pappso::PrecisionPtr precisionPtr,
-                                         bool applyMzShift,
-                                         pappso::pappso_double mzShift,
+                                         int binSizeDivisor,
                                          bool removeZeroValDataPoints)
   : m_smallestMz(minMz),
     m_greatestMz(maxMz),
     m_binningType(binningType),
     m_decimalPlaces(decimalPlaces),
     mp_precision(precisionPtr),
-    m_applyMzShift(applyMzShift),
-    m_mzShift(mzShift),
+    m_binSizeDivisor(binSizeDivisor),
     m_removeZeroValDataPoints(removeZeroValDataPoints)
 {
   if(mp_precision == nullptr)
     mp_precision = pappso::PrecisionFactory::getPpmInstance(20);
+
+  //qDebug() << "mp_precision:" << mp_precision->toString();
 }
 
 
@@ -105,12 +105,13 @@ MzIntegrationParams::MzIntegrationParams(const MzIntegrationParams &other)
     m_binningType(other.m_binningType),
     m_decimalPlaces(other.m_decimalPlaces),
     mp_precision(other.mp_precision),
-    m_applyMzShift(other.m_applyMzShift),
-    m_mzShift(other.m_mzShift),
+    m_binSizeDivisor(other.m_binSizeDivisor),
     m_removeZeroValDataPoints(other.m_removeZeroValDataPoints)
 {
   if(mp_precision == nullptr)
-    mp_precision = pappso::PrecisionFactory::getPpmInstance(20);
+    mp_precision = pappso::PrecisionFactory::getResInstance(40000);
+
+  //qDebug() << "mp_precision:" << mp_precision->toString();
 }
 
 
@@ -135,8 +136,8 @@ MzIntegrationParams::operator=(const MzIntegrationParams &other)
   if(mp_precision == nullptr)
     mp_precision = pappso::PrecisionFactory::getPpmInstance(20);
 
-  m_applyMzShift            = other.m_applyMzShift;
-  m_mzShift                 = other.m_mzShift;
+  m_binSizeDivisor = other.m_binSizeDivisor;
+
   m_removeZeroValDataPoints = other.m_removeZeroValDataPoints;
 
   return *this;
@@ -184,18 +185,21 @@ MzIntegrationParams::getGreatestMz() const
   return m_greatestMz;
 }
 
+
 void
 MzIntegrationParams::setBinningType(BinningType binningType)
 {
   m_binningType = binningType;
 }
 
+
 BinningType
 MzIntegrationParams::getBinningType() const
 {
   return m_binningType;
 }
 
+
 void
 MzIntegrationParams::setDecimalPlaces(int decimal_places)
 {
@@ -226,16 +230,16 @@ MzIntegrationParams::getPrecision() const
 
 
 void
-MzIntegrationParams::setApplyMzShift(bool applyMzShift)
+MzIntegrationParams::setBinSizeDivisor(int divisor)
 {
-  m_applyMzShift = applyMzShift;
+  m_binSizeDivisor = divisor;
 }
 
 
-bool
-MzIntegrationParams::isApplyMzShift() const
+int
+MzIntegrationParams::getBinSizeDivisor() const
 {
-  return m_applyMzShift;
+  return m_binSizeDivisor;
 }
 
 
@@ -253,20 +257,6 @@ MzIntegrationParams::isRemoveZeroValDataPoints() const
 }
 
 
-void
-MzIntegrationParams::setMzShift(double value)
-{
-  m_mzShift = value;
-}
-
-
-double
-MzIntegrationParams::getMzShift() const
-{
-  return m_mzShift;
-}
-
-
 //! Reset the instance to default values.
 void
 MzIntegrationParams::reset()
@@ -278,8 +268,7 @@ MzIntegrationParams::reset()
   // Special case for this member datum
   mp_precision = pappso::PrecisionFactory::getPpmInstance(20);
 
-  m_applyMzShift            = false;
-  m_mzShift                 = 0;
+  m_binSizeDivisor          = 1;
   m_removeZeroValDataPoints = false;
 }
 
@@ -289,6 +278,9 @@ MzIntegrationParams::isValid() const
 {
   int errors = 0;
 
+  if(!m_binSizeDivisor)
+    errors += 1;
+
   if(m_binningType != BinningType::NONE)
     {
       // qDebug() << "m_smallestMz:" << m_smallestMz;
@@ -330,7 +322,7 @@ std::vector<double>
 MzIntegrationParams::createBins()
 {
 
-  // qDebug();
+  //qDebug() << "mp_precision:" << mp_precision->toString();
 
   std::vector<double> bins;
 
@@ -389,21 +381,33 @@ MzIntegrationParams::createBins(pappso::MassSpectrumCstSPtr mass_spectrum_csp)
 std::vector<double>
 MzIntegrationParams::createArbitraryBins()
 {
-
-  // qDebug();
-
   // Now starts the tricky stuff. Depending on how the binning has been
   // configured, we need to take diverse actions.
 
-  // qDebug() << "Bin specification:" << mp_precision->toString();
+  //qDebug() << "Bin size specification:" << mp_precision->toString();
 
   pappso::pappso_double min_mz = m_smallestMz;
   pappso::pappso_double max_mz = m_greatestMz;
 
+  //qDebug() << "m_smallestMz:" << m_smallestMz
+           //<< "m_greatestMz:" << m_greatestMz;
+
   // qDebug() << QString::asprintf("min_mz: %.6f\n", min_mz)
   //<< QString::asprintf("max_mz: %.6f\n", max_mz);
 
-  pappso::pappso_double binSize = mp_precision->delta(min_mz);
+  pappso::pappso_double binSize;
+
+  if(mp_precision->unit() == PrecisionUnit::res)
+    {
+      double resolution_based_bin_size = mp_precision->delta(min_mz);
+      binSize = resolution_based_bin_size / m_binSizeDivisor;
+
+      //qDebug() << "With res-based bin size, the uncorrected bin size:"
+               //<< resolution_based_bin_size
+               //<< "and the final binSize:" << binSize;
+    }
+  else
+    binSize = mp_precision->delta(min_mz);
 
   // qDebug() << QString::asprintf(
   //"binSize is the precision delta for min_mz: %.6f\n", binSize);
@@ -411,7 +415,7 @@ MzIntegrationParams::createArbitraryBins()
   // Only compute the decimal places if they were not configured already.
   if(m_decimalPlaces == -1)
     {
-      qDebug() << "Now checking how many decimal places are needed.";
+      //qDebug() << "Now checking how many decimal places are needed.";
 
       // We want as many decimal places as there are 0s between the integral
       // part of the double and the first non-0 cipher.  For example, if
@@ -423,8 +427,8 @@ MzIntegrationParams::createArbitraryBins()
       //qDebug() << "With binSize" << binSize
                //<< " m_decimalPlaces was computed to be:" << m_decimalPlaces;
     }
-  //else
-    //qDebug() << "m_decimalPlaces: " << m_decimalPlaces;
+  // else
+  // qDebug() << "m_decimalPlaces: " << m_decimalPlaces;
 
   // Now that we have defined the value of m_decimalPlaces, let's use that
   // value.
@@ -474,8 +478,19 @@ MzIntegrationParams::createArbitraryBins()
       // double precision_delta = mp_precision->delta(previous_mz_bin);
       // qDebug() << "precision_delta: " << precision_delta;
 
-      double current_mz =
-        previous_mz_bin + mp_precision->delta(previous_mz_bin);
+      // In certain circumstances, the bin size is not enough to properly render
+      // hyper-high resolution data (like the theoretical isotopic cluster data
+      // generated in silico). In that case, the bin size, computed using the
+      // precision object, is divided by the m_binSizeDivisor, which normally is
+      // set to 1 as the default, that is, it has no effect.
+
+      double current_mz;
+
+      if(mp_precision->unit() == PrecisionUnit::res)
+        current_mz = previous_mz_bin +
+                     (mp_precision->delta(previous_mz_bin) / m_binSizeDivisor);
+      else
+        current_mz = previous_mz_bin + mp_precision->delta(previous_mz_bin);
 
       // qDebug() << QString::asprintf(
       //"previous_mzBin: %.6f and current_mz: %.6f\n",
@@ -715,23 +730,15 @@ MzIntegrationParams::toString(int offset, const QString &spacer) const
       text += spacer;
       text.append(QString("Bin size: %2\n")
                     .arg(mp_precision->toString().toLatin1().data()));
-    }
 
-  // Now other data that are independent of the bin settings.
-
-  text += lead;
-  text += spacer;
-  text +=
-    QString("Apply m/z shift: %1\n").arg(m_applyMzShift ? "true" : "false");
-
-  if(m_applyMzShift)
-    {
       text += lead;
       text += spacer;
       text += spacer;
-      text += QString("m/z shift: %1").arg(m_mzShift, 0, 'f', 6);
+      text.append(QString("Bin size divisor: %2\n").arg(m_binSizeDivisor));
     }
 
+  // Now other data that are independent of the bin settings.
+
   text += lead;
   text += spacer;
   text += QString("Remove 0-val data points: %1\n")
