@@ -91,8 +91,7 @@ class PMSPP_LIB_DECL MzIntegrationParams
                                   BinningType binningType,
                                   int decimalPlaces,
                                   pappso::PrecisionPtr precisionPtr,
-                                  bool applyMzShift,
-                                  pappso::pappso_double mzShift,
+                                  int binSizeDivisor,
                                   bool removeZeroValDataPoints);
 
   Q_INVOKABLE MzIntegrationParams(const MzIntegrationParams &other);
@@ -118,11 +117,8 @@ class PMSPP_LIB_DECL MzIntegrationParams
   Q_INVOKABLE void setPrecision(pappso::PrecisionPtr precisionPtr);
   Q_INVOKABLE pappso::PrecisionPtr getPrecision() const;
 
-  Q_INVOKABLE void setApplyMzShift(bool applyMzShift);
-  Q_INVOKABLE bool isApplyMzShift() const;
-
-  Q_INVOKABLE void setMzShift(double value);
-  Q_INVOKABLE double getMzShift() const;
+  void setBinSizeDivisor(int divisor);
+  int getBinSizeDivisor() const;
 
   Q_INVOKABLE void setRemoveZeroValDataPoints(bool removeOrNot = true);
   Q_INVOKABLE bool isRemoveZeroValDataPoints() const;
@@ -159,8 +155,9 @@ class PMSPP_LIB_DECL MzIntegrationParams
   // the bins.
   pappso::PrecisionPtr mp_precision =
     pappso::PrecisionFactory::getDaltonInstance(0.05);
-  bool m_applyMzShift             = false;
-  pappso::pappso_double m_mzShift = 0;
+
+  int m_binSizeDivisor = 1;
+
   bool m_removeZeroValDataPoints  = true;
 
   std::vector<double> createArbitraryBins();
