@@ -460,24 +460,30 @@ Trace::Trace(const std::vector<pappso_double> &xVector,
 
 
 size_t
-Trace::initialize(const QString space_sep_text)
+Trace::initialize(const QString &space_sep_text)
 {
   QStringList string_list = space_sep_text.split("\n", Qt::SkipEmptyParts);
 
-  //qDebug() << "Split text into" << string_list.size()
-           //<< "substrings:" << string_list;
-  ;
+  // qDebug() << "Split text into" << string_list.size()
+  //<< "substrings:" << string_list;
 
   for(int iter = 0; iter < string_list.size(); ++iter)
     {
       QString line = string_list.at(iter);
-      //qDebug() << "Now processing line:" << line;
+      // qDebug() << "Now processing line:" << line;
 
       // Returns a string that has whitespace removed from the start and the
       // end, and that has each sequence of internal whitespace replaced with a
       // single space.
       line = line.simplified();
 
+      // Remove any parentheses and replace comma and semicolumn with space.
+      // line.remove(QChar('('));
+      // line.remove(QChar(')'));
+
+      // line.replace(QChar(','), QChar(' '));
+      // line.replace(QChar(';'), QChar(' '));
+
       append(DataPoint(line));
     }
 
@@ -485,6 +491,34 @@ Trace::initialize(const QString space_sep_text)
 }
 
 
+size_t
+Trace::initialize(const QString &x_text, const QString &y_text)
+{
+  QStringList x_string_list = x_text.split("\n", Qt::SkipEmptyParts);
+  QStringList y_string_list = y_text.split("\n", Qt::SkipEmptyParts);
+
+  if(x_string_list.size() != y_string_list.size())
+    throw ExceptionNotPossible(
+      "trace.cpp -- ERROR x_text and y_text must have the same number of "
+      "lines.");
+
+  for(int iter = 0; iter < x_string_list.size(); ++iter)
+    {
+      QString x_line = x_string_list.at(iter);
+      QString y_line = y_string_list.at(iter);
+
+      // Returns a string that has whitespace removed from the start and the
+      // end, and that has each sequence of internal whitespace replaced with a
+      // single space.
+      x_line = x_line.simplified();
+      y_line = y_line.simplified();
+
+      append(DataPoint(x_line + " " + y_line));
+    }
+  return size();
+}
+
+
 Trace::Trace(
   const std::vector<std::pair<pappso_double, pappso_double>> &dataPoints)
 {
@@ -881,6 +915,44 @@ Trace::containsX(pappso_double value, PrecisionPtr precision_p) const
 }
 
 
+const DataPoint &
+Trace::minXDataPoint() const
+{
+  auto dataPoint = std::min_element(
+    begin(), end(), [](const DataPoint &a, const DataPoint &b) {
+      return (a.x < b.x);
+    });
+
+  if(dataPoint == end())
+    {
+      throw ExceptionOutOfRange(
+        QObject::tr("unable to get min peak x on spectrum size %1")
+          .arg(size()));
+    }
+
+  return (*dataPoint);
+}
+
+
+const DataPoint &
+Trace::maxXDataPoint() const
+{
+  auto dataPoint = std::max_element(
+    begin(), end(), [](const DataPoint &a, const DataPoint &b) {
+      return (a.x < b.x);
+    });
+
+  if(dataPoint == end())
+    {
+      throw ExceptionOutOfRange(
+        QObject::tr("unable to get max peak x on spectrum size %1")
+          .arg(size()));
+    }
+
+  return (*dataPoint);
+}
+
+
 const DataPoint &
 Trace::minYDataPoint() const
 {
@@ -919,6 +991,20 @@ Trace::maxYDataPoint() const
 }
 
 
+pappso_double
+Trace::minX() const
+{
+  return minXDataPoint().x;
+}
+
+
+pappso_double
+Trace::maxX() const
+{
+  return maxXDataPoint().x;
+}
+
+
 pappso_double
 Trace::minY() const
 {
@@ -984,21 +1070,46 @@ Trace::maxY(double mzStart, double mzEnd) const
 
 
 void
-Trace::sortX()
+Trace::sort(SortType sort_type, SortOrder sort_order)
 {
-  std::sort(begin(), end(), [](const DataPoint &a, const DataPoint &b) {
-    return (a.x < b.x);
-  });
+  if(sort_type == SortType::no_sort)
+    return;
+
+  if(sort_type == SortType::x)
+    return sortX(sort_order);
+  else
+    return sortY(sort_order);
 }
 
+
 void
-Trace::sortY()
+Trace::sortX(SortOrder sort_order)
 {
-  std::sort(begin(), end(), [](const DataPoint &a, const DataPoint &b) {
-    return (a.y > b.y);
-  });
+  if(sort_order == SortOrder::ascending)
+    std::sort(begin(), end(), [](const DataPoint &a, const DataPoint &b) {
+      return (a.x < b.x);
+    });
+  else
+    std::sort(begin(), end(), [](const DataPoint &a, const DataPoint &b) {
+      return (a.x > b.x);
+    });
 }
 
+
+void
+Trace::sortY(SortOrder sort_order)
+{
+  if(sort_order == SortOrder::ascending)
+    std::sort(begin(), end(), [](const DataPoint &a, const DataPoint &b) {
+      return (a.y < b.y);
+    });
+  else
+    std::sort(begin(), end(), [](const DataPoint &a, const DataPoint &b) {
+      return (a.y > b.y);
+    });
+}
+
+
 void
 Trace::unique()
 {
@@ -1046,15 +1157,56 @@ Trace::toString() const
 
   for(auto &&dataPoint : *this)
     {
-      text.append(QString("%1 %2\n")
-                    .arg(dataPoint.x, 0, 'f', 10)
-                    .arg(dataPoint.y, 0, 'f', 10));
+      text.append(QString("%1\n")
+                    .arg(dataPoint.toString()));
     }
 
   return text;
 }
 
 
+QByteArray
+Trace::xAsBase64Encoded() const
+{
+  QByteArray unencoded_array;
+
+  for(auto &&data_point : *this)
+    {
+      QByteArray local_array;
+      local_array.setNum(data_point.x, 'f', 12);
+      local_array.append("\n");
+
+      unencoded_array.append(local_array);
+    }
+
+  QByteArray base64_encoded_array = unencoded_array.toBase64(
+    QByteArray::Base64Encoding | QByteArray::OmitTrailingEquals);
+
+  return base64_encoded_array;
+}
+
+
+QByteArray
+Trace::yAsBase64Encoded() const
+{
+  QByteArray unencoded_array;
+
+  for(auto &&data_point : *this)
+    {
+      QByteArray local_array;
+      local_array.setNum(data_point.y, 'f', 12);
+      local_array.append("\n");
+
+      unencoded_array.append(local_array);
+    }
+
+  QByteArray base64_encoded_array = unencoded_array.toBase64(
+    QByteArray::Base64Encoding | QByteArray::OmitTrailingEquals);
+
+  return base64_encoded_array;
+}
+
+
 Trace &
 Trace::filter(const FilterInterface &filter)
 {
