@@ -32,6 +32,7 @@
 #pragma once
 
 #include <QString>
+#include <cstdint>
 
 namespace pappso
 {
@@ -57,6 +58,17 @@ typedef unsigned int uint;
 
 /*********** enumerations *********************************/
 
+/** \def TimeUnit (s, min, h)
+ */
+enum class TimeUnit
+{
+  none,
+  s,
+  min,
+  h,
+};
+
+
 /** \def PrecisionUnit ppm or dalton
  *
  */
@@ -127,7 +139,20 @@ enum class MzFormat : std::int8_t
 };
 
 
-/** \def MzFormat mz data file format types
+/** \def FileReaderType mass data file reader types
+ * 
+ */
+enum class FileReaderType
+{
+  pwiz,
+  xy,
+  tims,
+  tims_frames,
+  tims_ms2,
+};
+
+
+/** \def AminoAcidChar Amino-acid full name and code correspondence
  *
  */
 enum class AminoAcidChar : char
@@ -414,7 +439,7 @@ enum class PeptideIon : std::int8_t
   x     = 13 ///< Cter acylium ions
 };
 
-/** \brief only usefull for inernal usefull
+/** \brief only useful for internal use
  * DO not change this value : it is used to define static array size
  */
 #define PEPTIDE_ION_TYPE_COUNT 14
