@@ -212,7 +212,7 @@ TimsData::TimsData(QDir timsDataDirectory)
       frame_record.tims_calibration_id = record.value(7).toULongLong();
     }
 
-  mcsp_ms2Filter = std::make_shared<pappso::FilterSuiteString>(
+  mcsp_ms2Filter = std::make_shared<FilterSuiteString>(
     "chargeDeconvolution|0.02dalton mzExclusion|0.01dalton");
 
 
@@ -260,7 +260,7 @@ TimsData::openDatabaseConnection() const
   return qdb;
 }
 
-TimsData::TimsData([[maybe_unused]] const pappso::TimsData &other)
+TimsData::TimsData([[maybe_unused]] const TimsData &other)
 {
   qDebug();
 }
@@ -394,7 +394,7 @@ TimsData::getRawIndexFromCoordinate(std::size_t frame_id,
  * @param raw_index a number begining at 0, corresponding to a Tims Scan in
  * the order they lies in the binary data file
  */
-pappso::MassSpectrumCstSPtr
+MassSpectrumCstSPtr
 TimsData::getMassSpectrumCstSPtrByRawIndex(std::size_t raw_index)
 {
 
@@ -497,8 +497,8 @@ TimsData::getTimsMS1FrameIdRange(double rt_begin, double rt_end) const
   std::vector<std::size_t> tims_frameid_list;
   QSqlDatabase qdb = openDatabaseConnection();
   QSqlQuery q      = qdb.exec(QString("SELECT Frames.Id FROM Frames WHERE "
-                                 "Frames.MsMsType=0 AND (Frames.Time>=%1) AND "
-                                 "(Frames.Time<=%2) ORDER BY Frames.Time;")
+                                      "Frames.MsMsType=0 AND (Frames.Time>=%1) AND "
+                                      "(Frames.Time<=%2) ORDER BY Frames.Time;")
                            .arg(rt_begin)
                            .arg(rt_end));
   if(q.lastError().isValid())
@@ -609,11 +609,11 @@ TimsData::getTimsFrameCstSPtr(std::size_t timsId)
 }
 
 
-pappso::MassSpectrumCstSPtr
+MassSpectrumCstSPtr
 TimsData::getMassSpectrumCstSPtr(std::size_t timsId, std::size_t scanNum)
 {
   qDebug() << " timsId=" << timsId << " scanNum=" << scanNum;
-  pappso::TimsFrameCstSPtr frame = getTimsFrameCstSPtrCached(timsId);
+  TimsFrameCstSPtr frame = getTimsFrameCstSPtrCached(timsId);
 
   return frame->getMassSpectrumCstSPtr(scanNum);
 }
@@ -652,16 +652,16 @@ TimsData::getPrecursorsFromMzRtCharge(int charge,
   QSqlQuery q      = qdb.exec(
     QString(
       "SELECT Frames.Time, Precursors.MonoisotopicMz, Precursors.Charge, "
-      "Precursors.Id, Frames.Id, PasefFrameMsMsInfo.ScanNumBegin, "
-      "PasefFrameMsMsInfo.scanNumEnd "
-      "FROM Frames "
-      "INNER JOIN PasefFrameMsMsInfo ON Frames.Id = PasefFrameMsMsInfo.Frame "
-      "INNER JOIN Precursors ON PasefFrameMsMsInfo.Precursor = Precursors.Id "
-      "WHERE Precursors.Charge == %1 "
-      "AND Precursors.MonoisotopicMz > %2 -0.01 "
-      "AND Precursors.MonoisotopicMz < %2 +0.01 "
-      "AND Frames.Time >= %3 -1 "
-      "AND Frames.Time < %3 +1; ")
+           "Precursors.Id, Frames.Id, PasefFrameMsMsInfo.ScanNumBegin, "
+           "PasefFrameMsMsInfo.scanNumEnd "
+           "FROM Frames "
+           "INNER JOIN PasefFrameMsMsInfo ON Frames.Id = PasefFrameMsMsInfo.Frame "
+           "INNER JOIN Precursors ON PasefFrameMsMsInfo.Precursor = Precursors.Id "
+           "WHERE Precursors.Charge == %1 "
+           "AND Precursors.MonoisotopicMz > %2 -0.01 "
+           "AND Precursors.MonoisotopicMz < %2 +0.01 "
+           "AND Frames.Time >= %3 -1 "
+           "AND Frames.Time < %3 +1; ")
       .arg(charge)
       .arg(mz_val)
       .arg(rt_sec));
@@ -874,7 +874,7 @@ TimsData::getQualifiedMassSpectrumByRawIndex(
     }
   catch(PappsoException &error)
     {
-      throw pappso::PappsoException(
+      throw PappsoException(
         QObject::tr("Error TimsData::getQualifiedMassSpectrumByRawIndex "
                     "spectrum_index=%1 :\n%2")
           .arg(spectrum_index)
@@ -1033,7 +1033,7 @@ TimsData::getQualifiedMs1MassSpectrumByPrecursorId(
                              spectrum_descr.scan_mobility_start,
                              spectrum_descr.scan_mobility_end));
 
-          pappso::Trace trace(combiner_result);
+          Trace trace(combiner_result);
           qDebug();
 
           if(trace.size() > 0)
@@ -1104,7 +1104,7 @@ TimsData::getTimsFrameCstSPtrCached(std::size_t timsId)
           return tims_frame;
         }
     }
-  pappso::TimsFrameCstSPtr frame_sptr = getTimsFrameCstSPtr(timsId);
+  TimsFrameCstSPtr frame_sptr = getTimsFrameCstSPtr(timsId);
 
   // locker.relock();
   qDebug();
@@ -1126,7 +1126,7 @@ if(std::find(m_someoneIsLoadingFrameId.begin(),
     m_someoneIsLoadingFrameId.push_back(timsId);
     qDebug();
     //locker.unlock();
-    pappso::TimsFrameCstSPtr frame_sptr = getTimsFrameCstSPtr(timsId);
+    TimsFrameCstSPtr frame_sptr = getTimsFrameCstSPtr(timsId);
 
    // locker.relock();
     qDebug();
@@ -1167,18 +1167,18 @@ else
 }
 
 void
-TimsData::setMs2FilterCstSPtr(pappso::FilterInterfaceCstSPtr &filter)
+TimsData::setMs2FilterCstSPtr(FilterInterfaceCstSPtr &filter)
 {
   mcsp_ms2Filter = filter;
 }
 void
-TimsData::setMs1FilterCstSPtr(pappso::FilterInterfaceCstSPtr &filter)
+TimsData::setMs1FilterCstSPtr(FilterInterfaceCstSPtr &filter)
 {
   mcsp_ms1Filter = filter;
 }
 
-pappso::XicCoordTims
-pappso::TimsData::getXicCoordTimsFromPrecursorId(std::size_t precursor_id,
+XicCoordTims
+TimsData::getXicCoordTimsFromPrecursorId(std::size_t precursor_id,
                                                  PrecisionPtr precision_ptr)
 {
 
@@ -1216,15 +1216,15 @@ pappso::TimsData::getXicCoordTimsFromPrecursorId(std::size_t precursor_id,
           QSqlDatabase qdb = openDatabaseConnection();
           QSqlQuery q      = qdb.exec(
             QString("SELECT Precursors.id, "
-                    "min(Frames.Time), "
-                    "min(PasefFrameMsMsInfo.ScanNumBegin), "
-                    "max(PasefFrameMsMsInfo.ScanNumEnd), "
-                    "Precursors.MonoisotopicMz "
-                    "FROM "
-                    "PasefFrameMsMsInfo INNER JOIN Precursors ON "
-                    "PasefFrameMsMsInfo.Precursor=Precursors.Id INNER JOIN "
-                    "Frames ON PasefFrameMsMsInfo.Frame=Frames.Id "
-                    "GROUP BY Precursors.id;"));
+                         "min(Frames.Time), "
+                         "min(PasefFrameMsMsInfo.ScanNumBegin), "
+                         "max(PasefFrameMsMsInfo.ScanNumEnd), "
+                         "Precursors.MonoisotopicMz "
+                         "FROM "
+                         "PasefFrameMsMsInfo INNER JOIN Precursors ON "
+                         "PasefFrameMsMsInfo.Precursor=Precursors.Id INNER JOIN "
+                         "Frames ON PasefFrameMsMsInfo.Frame=Frames.Id "
+                         "GROUP BY Precursors.id;"));
           if(q.lastError().isValid())
             {
               qDebug();
@@ -1345,7 +1345,7 @@ TimsData::getRawMs2ByPrecursorId(std::size_t precursor_index)
             }
           // QMutexLocker locker(&m_mutex_spectrum);
           qDebug();
-          pappso::TimsFrameCstSPtr tims_frame, previous_frame;
+          TimsFrameCstSPtr tims_frame, previous_frame;
           // TracePlusCombiner combiner;
           // MapTrace combiner_result;
           for(std::size_t tims_id : tims_frame_list)
@@ -1468,7 +1468,7 @@ TimsData::getQualifiedMs2MassSpectrumByPrecursorId(
 
       // QMutexLocker locker(&m_mutex_spectrum);
       qDebug();
-      pappso::TimsFrameBaseCstSPtr tims_frame, previous_frame;
+      TimsFrameBaseCstSPtr tims_frame, previous_frame;
       // TracePlusCombiner combiner;
       // MapTrace combiner_result;
       std::map<quint32, quint32> raw_spectrum;
@@ -1558,7 +1558,7 @@ TimsData::getQualifiedMs2MassSpectrumByPrecursorId(
         {
           qDebug() << " precursor_index=" << spectrum_descr.precursor_id;
           // peak_pick.filter(trace);
-          pappso::Trace trace;
+          Trace trace;
           if(m_builtinMs2Centroid)
             {
               trace =
@@ -1584,7 +1584,7 @@ TimsData::getQualifiedMs2MassSpectrumByPrecursorId(
                   // FilterTriangle filter;
                   // filter.setTriangleSlope(50, 0.02);
                   // filter.filter(trace);
-                  // trace.filter(pappso::FilterHighPass(10));
+                  // trace.filter(FilterHighPass(10));
                   mcsp_ms2Filter->filter(trace);
                 }
 
@@ -1624,9 +1624,9 @@ TimsData::getQualifiedMs2MassSpectrumByPrecursorId(
 }
 
 void
-pappso::TimsData::ms2ReaderSpectrumCollectionByMsLevel(
+TimsData::ms2ReaderSpectrumCollectionByMsLevel(
   const MsRunIdCstSPtr &msrun_id,
-  pappso::SpectrumCollectionHandlerInterface &handler,
+  SpectrumCollectionHandlerInterface &handler,
   unsigned int ms_level)
 {
   qDebug() << " ms_level=" << ms_level;
@@ -1686,6 +1686,7 @@ pappso::TimsData::ms2ReaderSpectrumCollectionByMsLevel(
   qDebug() << "qprecursor_list.isSelect()=" << qprecursor_list.isSelect();
   bool first = true;
   SpectrumDescr spectrum_descr;
+
   /*
 std::size_t i = 0;
 while(qprecursor_list.next())
@@ -1693,12 +1694,13 @@ while(qprecursor_list.next())
                          qDebug() << "i=" << i;
                          i++;
                          }*/
+
   qprecursor_list.last(); // strange bug : get the last sql record and get
-  // back, unless it will not retrieve all records.
+  // back, otherwise it will not retrieve all records.
 
   qDebug() << "qprecursor_list.at()=" << qprecursor_list.at();
   qprecursor_list.first();
-  std::vector<pappso::TimsData::SpectrumDescr> spectrum_description_list;
+  std::vector<TimsData::SpectrumDescr> spectrum_description_list;
   spectrum_descr.precursor_id = 0;
   // std::size_t i = 0;
 
@@ -1801,14 +1803,14 @@ while(qprecursor_list.next())
 
 
       TimsData *itself                                            = this;
-      pappso::SpectrumCollectionHandlerInterface *pointer_handler = &handler;
+      SpectrumCollectionHandlerInterface *pointer_handler = &handler;
 
 
       std::function<std::vector<QualifiedMassSpectrum>(
-        const pappso::TimsData::SpectrumDescr &)>
+        const TimsData::SpectrumDescr &)>
         map_function_generate_spectrum =
           [itself, msrun_id, pointer_handler, ms_level](
-            const pappso::TimsData::SpectrumDescr &spectrum_descr)
+            const TimsData::SpectrumDescr &spectrum_descr)
         -> std::vector<QualifiedMassSpectrum> {
         std::vector<QualifiedMassSpectrum> mass_spectrum_list;
         itself->ms2ReaderGenerateMS1MS2Spectrum(msrun_id,
@@ -1858,12 +1860,13 @@ while(qprecursor_list.next())
 }
 
 
+
 void
-pappso::TimsData::ms2ReaderGenerateMS1MS2Spectrum(
+TimsData::ms2ReaderGenerateMS1MS2Spectrum(
   const MsRunIdCstSPtr &msrun_id,
   std::vector<QualifiedMassSpectrum> &qualified_mass_spectrum_list,
-  pappso::SpectrumCollectionHandlerInterface &handler,
-  const pappso::TimsData::SpectrumDescr &spectrum_descr,
+  SpectrumCollectionHandlerInterface &handler,
+  const TimsData::SpectrumDescr &spectrum_descr,
   unsigned int ms_level)
 {
 
@@ -1892,8 +1895,8 @@ pappso::TimsData::ms2ReaderGenerateMS1MS2Spectrum(
 }
 
 
-pappso::TimsData::SpectrumDescr
-pappso::TimsData::getSpectrumDescrWithPrecursorId(std::size_t precursor_id)
+TimsData::SpectrumDescr
+TimsData::getSpectrumDescrWithPrecursorId(std::size_t precursor_id)
 {
 
   SpectrumDescr spectrum_descr;
@@ -1914,9 +1917,9 @@ pappso::TimsData::getSpectrumDescrWithPrecursorId(std::size_t precursor_id)
                                  "Precursors.Intensity, "         // 13
                                  "Precursors.Parent "             // 14
                                  "FROM PasefFrameMsMsInfo "
-                                 "INNER JOIN Precursors ON "
-                                 "PasefFrameMsMsInfo.Precursor=Precursors.Id "
-                                 "WHERE Precursors.Id=%1;")
+                                      "INNER JOIN Precursors ON "
+                                      "PasefFrameMsMsInfo.Precursor=Precursors.Id "
+                                      "WHERE Precursors.Id=%1;")
                            .arg(precursor_id));
   if(q.lastError().isValid())
     {
@@ -1976,7 +1979,7 @@ pappso::TimsData::getSpectrumDescrWithPrecursorId(std::size_t precursor_id)
 }
 
 std::vector<double>
-pappso::TimsData::getRetentionTimeLine() const
+TimsData::getRetentionTimeLine() const
 {
   std::vector<double> timeline;
   timeline.reserve(m_mapFramesRecord.size());
@@ -1990,8 +1993,8 @@ pappso::TimsData::getRetentionTimeLine() const
   return timeline;
 }
 
-pappso::TimsData::SpectrumDescr
-pappso::TimsData::getSpectrumDescrWithScanCoordinate(
+TimsData::SpectrumDescr
+TimsData::getSpectrumDescrWithScanCoordinate(
   const std::pair<std::size_t, std::size_t> &scan_coordinate)
 {
 
@@ -2063,8 +2066,8 @@ pappso::TimsData::getSpectrumDescrWithScanCoordinate(
 
 
 void
-pappso::TimsData::fillSpectrumDescriptionWithSqlRecord(
-  pappso::TimsData::SpectrumDescr &spectrum_descr, QSqlQuery &qprecursor_list)
+TimsData::fillSpectrumDescriptionWithSqlRecord(
+  TimsData::SpectrumDescr &spectrum_descr, QSqlQuery &qprecursor_list)
 {
 
   spectrum_descr.tims_frame_list.clear();
@@ -2093,9 +2096,9 @@ pappso::TimsData::fillSpectrumDescriptionWithSqlRecord(
 
 
 void
-pappso::TimsData::rawReaderSpectrumCollectionByMsLevel(
-  const pappso::MsRunIdCstSPtr &msrun_id,
-  pappso::SpectrumCollectionHandlerInterface &handler,
+TimsData::rawReaderSpectrumCollectionByMsLevel(
+  const MsRunIdCstSPtr &msrun_id,
+  SpectrumCollectionHandlerInterface &handler,
   unsigned int ms_level)
 {
 
@@ -2362,5 +2365,11 @@ TimsData::getFrameIdDescrList() const
   return m_frameIdDescrList;
 }
 
+const std::vector<TimsFrameRecord> &
+TimsData::getTimsFrameRecordList() const
+{
+  return m_mapFramesRecord;
+}
+
 
 } // namespace pappso
