@@ -6,7 +6,7 @@
  */
 
 /*******************************************************************************
-œ* Copyright (c) 2019 Olivier Langella <Olivier.Langella@u-psud.fr>.
+ * Copyright (c) 2019 Olivier Langella <Olivier.Langella@u-psud.fr>.
  *
  * This file is part of the PAPPSOms++ library.
  *
@@ -34,11 +34,11 @@
 #include "../../massspectrum/qualifiedmassspectrum.h"
 #include "../../processing/filters/filterinterface.h"
 #include "../../msrun/xiccoord/xiccoordtims.h"
-#include "../../msrun/msrunreader.h"
 #include <deque>
 #include <QMutex>
 #include <QSqlQuery>
 #include "mzcalibration/mzcalibrationstore.h"
+#include "../../msrun/spectrumcollectionhandlerinterface.h"
 
 namespace pappso
 {
@@ -101,7 +101,7 @@ class PMSPP_LIB_DECL TimsData
    */
   std::size_t getTotalNumberOfScans() const;
 
-  /** @brief get the number of precursors analyzes by PASEF
+  /** @brief get the number of precursors analyzed by PASEF
    */
   std::size_t getTotalNumberOfPrecursors() const;
 
@@ -202,21 +202,21 @@ class PMSPP_LIB_DECL TimsData
     const MsRunIdCstSPtr &msrun_id,
     SpectrumCollectionHandlerInterface &handler,
     unsigned int ms_level);
-
+  
 
   /** @brief function to visit an MsRunReader and get each raw Spectrum in a
    * spectrum collection handler by Ms Levels
-   *
-   * this function will retrieve every scans as a qualified mass spectrum
-   */
+  *
+  * this function will retrieve every scans as a qualified mass spectrum
+  */
   void rawReaderSpectrumCollectionByMsLevel(
     const MsRunIdCstSPtr &msrun_id,
     SpectrumCollectionHandlerInterface &handler,
     unsigned int ms_level);
 
-  /** @brief get cumulated raw signal for a given precursor
-   * only to use to see the raw signal
-   *
+  /** @brief get cumulated raw signal for a given precursorCMakeLists.txt.userCMakeLists.txt.userCMakeLists.txt.user
+  * only to use to see the raw signal
+  *
    * @param precursor_index precursor index to extract signal from
    * @result a map of integers, x=time of flights, y= intensities
    */
@@ -250,6 +250,7 @@ class PMSPP_LIB_DECL TimsData
   void setMonoThread(bool is_mono_thread);
 
   const std::vector<FrameIdDescr> &getFrameIdDescrList() const;
+  const std::vector<TimsFrameRecord> &getTimsFrameRecordList() const;
 
 
   private:
