@@ -38,6 +38,7 @@
 
 
 /////////////////////// QCustomPlot
+#include <cstddef>
 #include <qcustomplot.h>
 
 
@@ -46,6 +47,7 @@
 #include "baseplotwidget.h"
 #include "colormapplotconfig.h"
 #include "../../trace/trace.h"
+#include "../../vendors/tims/timsframe.h"
 
 
 namespace pappso
@@ -63,6 +65,7 @@ class PMSPP_LIB_DECL BaseColorMapPlotWidget : public BasePlotWidget
   Q_OBJECT;
 
   public:
+  explicit BaseColorMapPlotWidget(QWidget *parent);
   explicit BaseColorMapPlotWidget(QWidget *parent,
                                   const QString &x_axis_label,
                                   const QString &y_axis_label);
@@ -79,11 +82,21 @@ class PMSPP_LIB_DECL BaseColorMapPlotWidget : public BasePlotWidget
     const ColorMapPlotConfig color_map_plot_config,
     const QColor &color);
 
+  virtual QCPColorMap *
+  addColorMap(const TimsFrame &tims_frame,
+              const ColorMapPlotConfig color_map_plot_config,
+              const QColor &color);
+
   virtual void transposeAxes();
 
   // Change the scale of the intensity to log10 (color, z virtual axis)
   virtual void zAxisScaleToLog10();
   virtual void zAxisFilterLowPassPercentage(double threshold_percentage);
+  
+  /** @brief fix maximum value for the intensity
+   */
+  virtual void zAxisFilterLowPassThreshold(double threshold);
+  
   virtual void zAxisFilterHighPassPercentage(double threshold_percentage);
 
   virtual void zAxisDataResetToOriginal();
@@ -100,7 +113,11 @@ class PMSPP_LIB_DECL BaseColorMapPlotWidget : public BasePlotWidget
                                 const QColor &new_color) override;
   virtual QColor getPlottingColor(int index = 0) const override;
 
-  QString dataToString();
+  void dataTo3ColString(QString &data_string);
+  void dataToMatrixString(QString &data_string, bool detailed = false);
+
+  void currentXaxisRangeIndices(int &lower, int &upper);
+  void currentYaxisRangeIndices(int &lower, int &upper);
 
   signals:
 
