@@ -28,6 +28,7 @@
 
 // ./tests/catch2-only-tests [MemTimsData] -s
 // ./tests/catch2-only-tests [MonothreadTimsData] -s
+// ./tests/catch2-only-tests [rusconi] -s
 
 
 #include <catch2/catch.hpp>
@@ -257,3 +258,104 @@ TEST_CASE("Check monothread usage of timsdata reader.", "[MonothreadTimsData]")
 
 #endif
 }
+
+
+TEST_CASE("Check speed of timsdata reader.", "[rusconi]")
+{
+  // VIRT 484Mo => 666Mo scan num="23944"
+  qSetMessagePattern(QString("%{file}@%{line}, %{function}(): %{message}"));
+#if USEPAPPSOTREE == 1
+  INFO("Test case start");
+
+  /*
+  pappso::MsFileAccessor file_access_A01(
+    //     "/gorgone/pappso/data_extraction_pappso/mzXML/"
+    "/gorgone/pappso/versions_logiciels_pappso/masschroq/donnees/"
+    "PXD014777_maxquant_timstof/"
+    "20180809_120min_200ms_WEHI25_brute20k_timsON_100ng_HYE124A_Slot1-7_1_890."
+    "d",
+    "");
+*/
+
+  pappso::MsFileAccessor file_access_A01(
+    //     "/gorgone/pappso/data_extraction_pappso/mzXML/"
+    "/gorgone/pappso/fichiers_fabricants/Bruker/tims_doc/tdf-sdk/example_data/"
+    "200ngHeLaPASEF_2min_compressed.d",
+    "");
+
+  /*
+  pappso::MsFileAccessor file_access_A01(
+    //     "/gorgone/pappso/data_extraction_pappso/mzXML/"
+    "/home/langella/data1/bruker/5-18-2021_1_robert_28_mic02-std_1354.d",
+    "");
+*/
+  INFO(QString("number of runIds = %1")
+         .arg(file_access_A01.getMsRunIds().size())
+         .toStdString());
+
+  QTextStream outputStream(stdout, QIODevice::WriteOnly);
+  UiMonitorText monitor(outputStream);
+
+
+  pappso::MsRunReaderSPtr p_reader;
+  p_reader =
+    file_access_A01.msRunReaderSp(file_access_A01.getMsRunIds().front());
+
+
+  Trace tic = p_reader.get()->getTicChromatogram();
+  
+  qWarning() << tic.toString();
+  INFO(tic.toString().toStdString());
+/*
+  // 517760
+  // REQUIRE(p_reader.get()->spectrumListSize() == 517760);
+  class Translator : public SpectrumCollectionHandlerInterface
+  {
+    public:
+    Translator(){};
+    virtual ~Translator(){};
+    virtual void
+    setQualifiedMassSpectrum(const QualifiedMassSpectrum &spectrum) override
+    {
+      qDebug() << spectrum.toString();
+    };
+    virtual bool
+    needPeakList() const override
+    {
+      return true;
+    };
+
+    private:
+  };
+
+  Translator reader_handler;
+
+  reader_handler.setNeedMsLevelPeakList(1, true);
+  reader_handler.setNeedMsLevelPeakList(2, true);
+  // reader_handler.setNeedMsLevelPeakList(2,false);
+
+  p_reader.get()->readSpectrumCollectionByMsLevel(reader_handler, 1);
+  // p_reader.get()->readSpectrumCollection(reader_handler);
+
+  QFile output_file("/dev/null");
+  // qDebug() << " TsvDirectoryWriter::writeSheet " <<
+  // QFileInfo(*_p_ofile).absoluteFilePath();
+  REQUIRE(output_file.open(QIODevice::WriteOnly));
+  pappso::UiMonitorVoid monitor_null;
+
+  pappso::MzxmlOutput mzxml_ouput(monitor_null,
+                                  QTextStream(&output_file).device());
+
+  mzxml_ouput.setReadAhead(true);
+  // mzxml_ouput.maskMs1(true);
+  QThreadPool::globalInstance()->setMaxThreadCount(10);
+  mzxml_ouput.write(p_reader.get());
+
+  mzxml_ouput.close();
+  */
+#elif USEPAPPSOTREE == 1
+
+  cout << std::endl << "..:: NO test TIMS TDF parsing ::.." << std::endl;
+
+#endif
+}
