@@ -269,12 +269,12 @@ TEST_CASE("Amino Acid code test suite.", "[AaCode]")
             aa_code.getAa((uint8_t)7).getMass());
 
     aa_code.addAaModification('C', AaModification::getInstance("MOD:00397"));
-    
-    
+
+
     REQUIRE(aa_code.getAaCode('M') == 13);
     REQUIRE(aa_code.getAaCode('A') == 2);
     REQUIRE(aa_code.getAaCode('I') == 7);
-    
+
     REQUIRE(aa_code.getAa('C').getMass() ==
             Approx(160.0306486807).margin(0.00001));
     REQUIRE(aa_code.getAaCode('C') == 17);
@@ -362,8 +362,8 @@ TEST_CASE("Amino Acid string codec test suite.", "[AaStringCodec]")
     REQUIRE(codec.getLimitMax(5) < std::numeric_limits<uint32_t>::max());
     REQUIRE(codec.getLimitMax(6) < std::numeric_limits<uint32_t>::max());
     REQUIRE(codec.getLimitMax(7) < std::numeric_limits<uint32_t>::max());
-    REQUIRE_FALSE((uint64_t)codec.getLimitMax(8) <
-                  (uint64_t)std::numeric_limits<uint32_t>::max());
+    // amino acid code is safe on all platform using at maximum 7 amino acids
+    // some architectures ar ok with 8 (armel)
     REQUIRE(codec.getLimitMax(5) == 3199999);
 
 
