@@ -61,9 +61,9 @@ TEST_CASE("Constructing MassSpectrumPlusCombiner objects.",
 }
 
 
-#if !defined (__i386__)
+#if !defined(__i386__)
 
-    // This test unbelievable does not pass on i386...
+// This test unbelievable does not pass on i386...
 
 TEST_CASE("Performing combinations with MassSpectrumPlusCombiner",
           "[MassSpectrumPlusCombiner][combinations]")
@@ -144,14 +144,14 @@ TEST_CASE("Performing combinations with MassSpectrumPlusCombiner",
     int decimal_places = 5;
     pappso::PrecisionPtr precision_p =
       pappso::PrecisionFactory::getDaltonInstance(0.05);
+    bool binSizeDivisor = 6;
 
     MzIntegrationParams mz_integration_params(610.02,
                                               611.97,
                                               BinningType::ARBITRARY,
                                               decimal_places,
                                               precision_p,
-                                              false,
-                                              0.0,
+                                              binSizeDivisor,
                                               true);
 
     // Check that it does not compute bins, since BinningType::NONE.
@@ -175,9 +175,9 @@ TEST_CASE("Performing combinations with MassSpectrumPlusCombiner",
 
     mass_spectrum_combiner.combine(map_trace, mass_spectrum1);
 
-    //std::cout << std::setprecision(10)
-              //<< "First map item x: " << map_trace.begin()->first
-              //<< " y: " << map_trace.begin()->second << std::endl;
+    // std::cout << std::setprecision(10)
+    //<< "First map item x: " << map_trace.begin()->first
+    //<< " y: " << map_trace.begin()->second << std::endl;
 
     REQUIRE(map_trace.size() == 20);
     REQUIRE(map_trace[610.02000] == 12963.5715942383);
@@ -270,14 +270,14 @@ TEST_CASE("Performing combinations with MassSpectrumPlusCombiner",
     int decimal_places = 5;
     pappso::PrecisionPtr precision_p =
       pappso::PrecisionFactory::getDaltonInstance(0.05);
+    bool binSizeDivisor = 6;
 
     MzIntegrationParams mz_integration_params(610.02,
                                               610.975,
                                               BinningType::ARBITRARY,
                                               decimal_places,
                                               precision_p,
-                                              false,
-                                              0.0,
+                                              binSizeDivisor,
                                               true);
 
     // Check that it does not compute bins, since BinningType::NONE.
