@@ -2,6 +2,7 @@
 
 #include <QDebug>
 
+#include <limits>
 #include <pappsomspp/processing/filters/savgolfilter.h>
 #include <pappsomspp/processing/combiners/mzintegrationparams.h>
 #include <pappsomspp/utils.h>
@@ -116,7 +117,15 @@ TEST_CASE("Create bins with Da-based bin size", "[MzIntegrationParams]")
     // that mz value incremented by the delta (that is the size of the bin that
     // is created using an increment of 0.05).
 
-    REQUIRE(bins.back() == 1800.374 + precision_p->delta(1800.374));
+    double manual_value = bins.front() + precision_p->delta(bins.front());
+
+    // Below: if abs(1.0 - 1.2) is less or equal to 0.2 -> success
+    //REQUIRE_THAT(1.0, Catch::Matchers::WithinAbs(1.2, 0.2)); // success
+    //REQUIRE_THAT(1.2, Catch::Matchers::WithinAbs(1.1, 0.2)); // success
+    //REQUIRE_THAT(1.0, Catch::Matchers::WithinAbs(1.3, 0.2)); // failure
+    //REQUIRE_THAT(1.3, Catch::Matchers::WithinAbs(1.0, 0.2)); // failure
+
+    REQUIRE_THAT(bins.back(), Catch::Matchers::WithinAbs(manual_value, std::numeric_limits<double>::epsilon()*10));
   }
 }
 
