@@ -75,6 +75,10 @@ TEST_CASE("Test Peptide", "[Peptide]")
       <psimod position="1"  accession="MOD:01160"/>
       */
 
+    for(const pappso::Aa &amino_acid : peptide2)
+      {
+      }
+
     pappso::AaModificationP aaModcarba =
       AaModification::getInstance("MOD:00397");
     /*
