@@ -26,8 +26,8 @@
  *implementation
  ******************************************************************************/
 
+// ./tests/catch2-only-tests [scan15968] -s
 
-#define CATCH_CONFIG_MAIN
 #include <catch2/catch.hpp>
 #include <pappsomspp/mzrange.h>
 #include <pappsomspp/peptide/peptidenaturalisotopelist.h>
@@ -713,7 +713,10 @@ TEST_CASE("scan 15968 test suite.", "[scan15968]")
 
     // Spectrum::getHyperscore  "b"  itmap->second  1   1
     //  Spectrum::getHyperscore  "y"  itmap->second  9   362880
-
+    REQUIRE(hyperscore15968.getHyperscore() ==
+            Approx(29.088471341).margin(0.001));
+    REQUIRE(pep15968.getMz(1) == Approx(1275.73).margin(0.01));
+    REQUIRE(pep15968.getMz(2) == Approx(638.369).margin(0.001));
     /*
     <group id="15968" mh="1275.731419" z="2" rt="PT2843.58S" expect="1.7e-04"
   label="GRMZM5G815453_P01 P00874 Ribulose bisphosphate carboxylase large chain
