@@ -44,7 +44,6 @@
 #include <pappsomspp/pappsoexception.h>
 #include <pappsomspp/exception/exceptionnotfound.h>
 #include <pappsomspp/processing/filters/filtersuitestring.h>
-#include <solvers.h>
 #include "config.h"
 
 using namespace pappso;
@@ -71,16 +70,8 @@ TEST_CASE("Test Cardano's cubic solver", "[cubicsolver]")
     X.push_back(3);
     X.push_back(2);
 
-    alglib::real_1d_array polynom_array;
-    polynom_array.setcontent(X.size(), &(X[0]));
 
-    alglib::complex_1d_array m;
-    alglib::polynomialsolverreport rep;
-
-    alglib::polynomialsolve(polynom_array, X.size() - 1, m, rep);
-
-
-    REQUIRE(m[0].x == Approx(-0.32588));
+    // REQUIRE(m[0].x == Approx(-0.32588));
 
     InHousePolynomialSolverResult res;
     res = inHousePolynomialSolve(X);
@@ -101,16 +92,8 @@ TEST_CASE("Test Cardano's cubic solver", "[cubicsolver]")
     X.push_back(3);
     // X.push_back(2);
 
-    alglib::real_1d_array polynom_array;
-    polynom_array.setcontent(X.size(), &(X[0]));
 
-    alglib::complex_1d_array m;
-    alglib::polynomialsolverreport rep;
-
-    alglib::polynomialsolve(polynom_array, X.size() - 1, m, rep);
-
-
-    REQUIRE(m[0].x == Approx(-0.3271626093));
+    // REQUIRE(m[0].x == Approx(-0.3271626093));
 
     InHousePolynomialSolverResult res;
     res = inHousePolynomialSolve(X);
@@ -131,16 +114,8 @@ TEST_CASE("Test Cardano's cubic solver", "[cubicsolver]")
     // X.push_back(3);
     // X.push_back(2);
 
-    alglib::real_1d_array polynom_array;
-    polynom_array.setcontent(X.size(), &(X[0]));
 
-    alglib::complex_1d_array m;
-    alglib::polynomialsolverreport rep;
-
-    alglib::polynomialsolve(polynom_array, X.size() - 1, m, rep);
-
-
-    REQUIRE(m[0].x == Approx(-0.3214285714));
+    // REQUIRE(m[0].x == Approx(-0.3214285714));
 
     InHousePolynomialSolverResult res;
     res = inHousePolynomialSolve(X);
