@@ -37,6 +37,7 @@
 #include <QFile>
 #include <pappsomspp/precision.h>
 #include <pappsomspp/msrun/output/mgfoutput.h>
+#include <pappsomspp/processing/compartraces/cosinesimilarity.h>
 #include <pappsomspp/processing/filters/filterpeakdelta.h>
 #include <pappsomspp/processing/filters/filterresample.h>
 #include <pappsomspp/processing/filters/filterpass.h>
@@ -57,6 +58,35 @@
 using namespace pappso;
 using namespace std;
 
+TEST_CASE("test cosine similarity.", "[cosinesim]")
+{
+  // Set the debugging message formatting pattern.
+  qSetMessagePattern(QString("%{file}@%{line}, %{function}(): %{message}"));
+
+  // QCoreApplication a(argc, argv);
+  SECTION("..:: test trace filters ::..", "[cosinesim]")
+  {
+    //   OboPsiMod test;
+    MassSpectrum spectrum_simple =
+      readMgf(QString(CMAKE_SOURCE_DIR)
+                .append("/tests/data/peaklist_15046_simple_xt.mgf"));
+
+
+    CosineSimilarity cosine(pappso::PrecisionFactory::getDaltonInstance(0.02));
+
+    REQUIRE(cosine.similarity(spectrum_simple, spectrum_simple) ==
+            Approx(1.0).epsilon(0.004));
+
+    MassSpectrum orig = spectrum_simple;
+    pappso::FilterGreatestY(10).filter(spectrum_simple);
+
+    REQUIRE(cosine.similarity(orig, spectrum_simple) ==
+            Approx(0.963327).epsilon(0.004));
+
+    // AIADGSLLDLLR
+  }
+}
+
 TEST_CASE("trace filter peak delta.", "[filterpeakdelta]")
 {
   // Set the debugging message formatting pattern.
